=======
hierArc
=======


.. image:: https://img.shields.io/pypi/v/hierarc.svg
        :target: https://pypi.python.org/pypi/hierarc

.. image:: https://img.shields.io/travis/sibirrer/hierarc.svg
        :target: https://travis-ci.com/sibirrer/hierarc

.. image:: https://readthedocs.org/projects/hierarc/badge/?version=latest
        :target: https://hierarc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Hierarchical analysis of strong lensing systems to infer lens properties and cosmological parameters simultaneously


* Free software: BSD license
* Documentation: https://hierarc.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
